@@ -27,7 +27,7 @@
 class MediaPlayer2 : public QDBusAbstractAdaptor
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2") // Docs: http://www.mpris.org/2.1/spec/Root_Node.html
+    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2") // Docs: https://specifications.freedesktop.org/mpris-spec/latest/Media_Player.html
 
     Q_PROPERTY(bool CanRaise READ CanRaise)
     Q_PROPERTY(bool CanQuit READ CanQuit)
